==> kdemultimedia-3.1.tar.bz2: kdemultimedia-3.1/noatun/modules/marquis/marquis.h <==
// marquis.h
//
// Copyright (C) 2000 Neil Stevens <multivac@fcmail.com>
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
// THE AUTHOR(S) BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
// AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
// CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
// 
// Except as contained in this notice, the name(s) of the author(s) shall not be
// used in advertising or otherwise to promote the sale, use or other dealings
// in this Software without prior written authorization from the author(s).

#ifndef MARQUIS_H
#define MARQUIS_H

#include <noatun/plugin.h>
#include <noatun/app.h>
#include <kmainwindow.h>

class Player;

class Marquis : public KMainWindow, public SessionManagement
{
Q_OBJECT
NOATUNPLUGIND
public:
	Marquis();
	virtual ~Marquis();

	virtual void restore(void);
protected:
	virtual void saveGlobalProperties(KConfig *);
	virtual void readGlobalProperties(KConfig *);
};

#endif

==> kdemultimedia-3.5.10.tar.bz2: kdemultimedia-3.5.10/noatun/modules/marquis/marquis.h <==
// marquis.h
//
// Copyright (C) 2000 Neil Stevens <multivac@fcmail.com>
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
// THE AUTHOR(S) BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
// AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
// CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
// 
// Except as contained in this notice, the name(s) of the author(s) shall not be
// used in advertising or otherwise to promote the sale, use or other dealings
// in this Software without prior written authorization from the author(s).

#ifndef MARQUIS_H
#define MARQUIS_H

#include <noatun/plugin.h>
#include <noatun/app.h>
#include <kmainwindow.h>

class Player;

class Marquis : public KMainWindow, public SessionManagement
{
Q_OBJECT
NOATUNPLUGIND
public:
	Marquis();
	virtual ~Marquis();

	virtual void restore(void);
private:
	void saveSessionConfig(KConfig *);
	void readSessionConfig(KConfig *);
private slots:
	void dynamicSave();
	void dynamicRestore();
};

#endif
